@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---      Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010  QRW Software
+--   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-09-19 14:13:49 -0600 (Sun, 19 Sep 2010) $
---   $Revision: 4756 $
+--   $Date: 2011-11-05 11:04:14 -0600 (Sat, 05 Nov 2011) $
+--   $Revision: 4923 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -93,7 +93,6 @@ extern bool nwos_find_private_class_definition(char* name, ObjRef* class_ref);
 extern ObjCreateResult nwos_find_or_create_private_class_definition(char* name_of_class, ObjRef* ref);
 extern bool nwos_find_public_feature_definition(ObjRef* type_ref, char* name, int count, ObjRef* feat_ref);
 extern void nwos_find_or_create_public_feature_definition(ObjRef* type_ref, char* name, int count, ObjRef* feat_ref);
-extern size_t nwos_get_object_size(void* object);
 extern void nwos_read_class_definition(ObjRef* ref, C_struct_Class_Definition* class_def);
 
 
@@ -200,6 +199,8 @@ extern void nwos_list_cities_in_state(char* state);
 #define MAX_CHECKING_OBJ_SIZE        (sizeof(C_struct_Checking) + MAX_CHECKING_ID_SIZE)
 
 extern bool nwos_find_public_credit_union(char* name, ObjRef* ref);
+extern void nwos_list_public_credit_unions();
+
 extern void nwos_add_account();
 extern void nwos_list_accounts();
 
@@ -209,14 +210,37 @@ extern bool nwos_find_public_manufacturer(char* name, ObjRef* ref);
 extern void nwos_list_public_manufacturers();
 
 
+/* checksum stuff */
+
+extern bool nwos_find_md5(uint8 md5[MD5_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_sha1(uint8 sha1[SHA1_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_sha256(uint8 sha256[SHA256_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_sha512(uint8 sha512[SHA512_DIGEST_SIZE], ObjRef* ref);
+
+extern bool nwos_find_public_md5(uint8 md5[MD5_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_public_sha1(uint8 sha1[SHA1_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_public_sha256(uint8 sha256[SHA256_DIGEST_SIZE], ObjRef* ref);
+extern bool nwos_find_public_sha512(uint8 sha512[SHA512_DIGEST_SIZE], ObjRef* ref);
+
+extern ObjCreateResult nwos_create_md5(uint8 md5sum[MD5_DIGEST_SIZE], ObjRef* ref);
+extern ObjCreateResult nwos_create_sha1(uint8 sha1sum[SHA1_DIGEST_SIZE], ObjRef* ref);
+extern ObjCreateResult nwos_create_sha256(uint8 sha256sum[SHA256_DIGEST_SIZE], ObjRef* ref);
+extern ObjCreateResult nwos_create_sha512(uint8 sha512sum[SHA512_DIGEST_SIZE], ObjRef* ref);
+
+#ifndef USE_PREDEFINED_STRUCTS
+extern bool nwos_md5_less_than(C_struct_MD5sum* current, C_struct_MD5sum* other);
+extern bool nwos_sha1_less_than(C_struct_SHA1sum* current, C_struct_SHA1sum* other);
+extern bool nwos_sha256_less_than(C_struct_SHA256sum* current, C_struct_SHA256sum* other);
+extern bool nwos_sha512_less_than(C_struct_SHA512sum* current, C_struct_SHA512sum* other);
+#endif
+
+
 /* file stuff */
 
 #define MAX_PATH_OBJ_SIZE  (sizeof(C_struct_File_Path) + 4096)
 
 typedef enum { File_Not_Found, Checksums_Match, MD5_Sum_Mismatch, SHA1_Sum_Mismatch, SHA256_Sum_Mismatch, SHA512_Sum_Mismatch, Checksums_Mismatch } CheckFileResult;
 
-extern void nwos_list_public_credit_unions();
-
 extern void nwos_normalize_path(char* dst, char* src, size_t size);
 extern bool nwos_find_file_path(const char* path, ObjRef* ref);
 extern ObjCreateResult nwos_create_file_path(const char* path, ObjRef* ref);
@@ -224,12 +248,8 @@ extern bool nwos_file_path_to_string(ObjRef* ref, char* string, size_t size);
 extern int  nwos_number_of_files_for_path(ObjRef* path_ref);
 extern uint32 nwos_estimate_blocks_for_file(const char* path);
 extern bool nwos_file_path_to_path_and_file_association(ObjRef* path_ref, int index, ObjRef* assoc_ref);
-extern bool nwos_find_md5(uint8 md5[MD5_DIGEST_SIZE], ObjRef* ref);
-extern bool nwos_find_sha1(uint8 sha1[SHA1_DIGEST_SIZE], ObjRef* ref);
-extern bool nwos_find_sha256(uint8 sha256[SHA256_DIGEST_SIZE], ObjRef* ref);
-extern bool nwos_find_sha512(uint8 sha512[SHA512_DIGEST_SIZE], ObjRef* ref);
 extern bool nwos_find_path_and_file_association(ObjRef* path_ref, ObjRef* file_ref, TimeStamp mod_time, ObjRef* ref);
-typedef enum { MatchAll=0x00, IgnoreTime=0x01, IgnoreVfat=0x02, IgnorePath=0x04, IgnoreName=0x08 } MatchCode;
+typedef enum { MatchAll=0x00, IgnoreTime=0x01, IgnoreVfat=0x02, IgnorePath=0x04, IgnoreName=0x08, IgnoreCase=0x10 } MatchCode;
 extern bool nwos_find_matching_path_and_file_association(const char* path, const char* file, ObjRef* ref, MatchCode match);
 extern CheckFileResult nwos_check_file_checksums(const char* path);
 extern bool nwos_file_is_stored(ObjRef* association_ref);  /* returns true if data stored in system */
@@ -253,6 +273,11 @@ extern bool nwos_file_is_identical(ObjRef* assoc_ref, const char* path, MatchCod
 extern const char* nwos_check_invalid_type(mode_t mode);
 extern void nwos_check_directory_is_all_ok(const char* path);
 
+#ifndef USE_PREDEFINED_STRUCTS
+extern bool nwos_file_path_less_than(C_struct_File_Path* current, C_struct_File_Path* other);
+extern bool nwos_file_less_than(C_struct_File* current, C_struct_File* other);
+#endif
+
 #define MAX_FILES_PER_DISC_LIST 1000000
 #define MAX_SIZE_DISC_LIST (sizeof(C_struct_Disc_List) + sizeof(ObjRef) * MAX_FILES_PER_DISC_LIST)
 
