@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-10-06 08:06:23 -0600 (Tue, 06 Oct 2009) $
---   $Revision: 4384 $
+--   $Date: 2011-07-06 16:49:12 -0600 (Wed, 06 Jul 2011) $
+--   $Revision: 4906 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -146,6 +146,7 @@ typedef struct {
 
 extern void nwos_get_object_class(ObjRef* obj, ObjRef* object_class);
 extern void nwos_get_object_class_without_update(ObjRef* obj, ObjRef* object_class);
+extern size_t nwos_get_object_size(void* object);
 extern void nwos_fill_in_common_header(CommonHeader* common, ObjRef* ref, ObjRef* class_definition_ref);
 
 extern void nwos_read_object_headers_from_disk(ObjRef* ref, EveryObject* header);
@@ -156,5 +157,9 @@ extern void nwos_write_public_object_to_disk(ObjRef* ref, void* object, size_t s
 extern void nwos_overwrite_object_to_disk(ObjRef* ref, void* object, size_t size);
 extern void nwos_remove_object(ObjRef* ref);
 
+extern void* nwos_malloc_temporary_object(size_t size, ObjRef* temp_ref);
+extern void nwos_free_temporary_object(void* object);
+extern void nwos_free_temporary_object_from_reference(ObjRef* object);
+
 #endif
 
