@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-10-06 08:06:23 -0600 (Tue, 06 Oct 2009) $
---   $Revision: 4384 $
+--   $Date: 2011-02-19 13:24:40 -0700 (Sat, 19 Feb 2011) $
+--   $Revision: 4868 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -54,6 +54,17 @@
 #ifndef REFERENCE_LIST_H
 #define REFERENCE_LIST_H
 
+
+typedef struct {
+    ObjRef       class;
+    uint32       capacity;
+    uint32       count;
+    ObjRef       references[0];
+} Sorted_Reference_List;
+
+extern Sorted_Reference_List* nwos_get_sorted_reference_list(ObjRef* list_ref, ObjRef* class_ref);
+extern int nwos_find_object_in_sorted_reference_list(Sorted_Reference_List* list, ObjRef* temp_ref);
+
 extern void nwos_create_reference_list(ObjRef* for_obj, ObjRef* ref_list);
 extern void nwos_create_reference_list_with_existing_id(ObjRef* for_obj, ObjRef* ref_list);
 extern void nwos_read_reference_list_from_disk(ObjRef* ref, ReferenceList* object, size_t size);
@@ -68,6 +79,7 @@ extern ReferenceList* nwos_malloc_reference_list(ObjRef* ref);
 extern void nwos_free_reference_list(ReferenceList* ref_list);
 
 extern void nwos_flush_dirty_ref_lists();
+extern void nwos_free_ref_lists();
 
 #endif
 
