@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               Copyright (C) 2007, 2008, 2009, 2011  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-09-12 08:25:34 -0600 (Sun, 12 Sep 2010) $
---   $Revision: 4723 $
+--   $Date: 2011-09-11 12:19:44 -0600 (Sun, 11 Sep 2011) $
+--   $Revision: 4915 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -69,6 +69,8 @@ static void display_usage(char* prog_name)
     fprintf(stderr, "\n");
     fprintf(stderr, "  --compressed file\tuse file for archive.\n");
     fprintf(stderr, "  --help\t\tdisplay this message.\n");
+    fprintf(stderr, "  --ignore-case\t\tdon't require case of file path to match.\n");
+    fprintf(stderr, "  --ignore-path\t\tdon't require file path to match.\n");
     fprintf(stderr, "  --ignore-time\t\tdon't require time stamp to match.\n");
     fprintf(stderr, "  --ignore-vfat-inaccuracy\t\tVFAT time is only accurate to two seconds.\n");
     fprintf(stderr, "  --public\t\tverify files against public data.\n");
@@ -211,7 +213,7 @@ bool process_file(const char* path, MatchCode match, Remove_Option remove_option
     {
 	printf("is a directory and -r or --recursive was not specified, ignored.\n");
     }
-    else if (nwos_find_matching_path_and_file_association(NULL, path, &ref, match))
+    else if (nwos_find_matching_path_and_file_association(NULL, path, &ref, match))       /* reference returned may be a temporary object */
     {
 	if (remove_option != Do_Not_Remove)
 	{
@@ -264,6 +266,8 @@ bool process_file(const char* path, MatchCode match, Remove_Option remove_option
 	{
 	    printf("found: %02x%02x%02x%02x\n", ref.id[0], ref.id[1], ref.id[2], ref.id[3]);
 	}
+
+	if (nwos_is_temporary_reference(&ref)) nwos_free_temporary_object_from_reference(&ref);
     }
     else
     {
@@ -421,6 +425,14 @@ int main(int argc, char* argv[])
 	{
 	    do_recursive = true;
 	}
+	else if (strcmp(argv[i], "--ignore-case") == 0)
+	{
+	    match |= IgnoreCase;
+	}
+	else if (strcmp(argv[i], "--ignore-path") == 0)
+	{
+	    match |= IgnorePath;
+	}
 	else if (strcmp(argv[i], "--ignore-time") == 0)
 	{
 	    match |= IgnoreTime;
