@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---                     Copyright (C) 2008, 2009  QRW Software
+--                  Copyright (C) 2008, 2009, 2011  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-10-06 08:06:23 -0600 (Tue, 06 Oct 2009) $
---   $Revision: 4384 $
+--   $Date: 2011-05-17 18:59:39 -0600 (Tue, 17 May 2011) $
+--   $Revision: 4900 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -51,7 +51,7 @@
 
 
 #include <string.h>
-#include "../objectify.h"
+#include "objectify.h"
 
 void wrapper_every_object_references(EveryObject* obj, ObjRef* ref)
 {
