@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-01-17 15:01:51 -0700 (Sun, 17 Jan 2010) $
---   $Revision: 4463 $
+--   $Date: 2010-10-22 07:02:17 -0600 (Fri, 22 Oct 2010) $
+--   $Revision: 4793 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -60,8 +60,9 @@
 
 static char* extra_names[] = 
 {
-  "barack", "birchard", "chip", "chipp", "cunningham", "delano", "elder",
-  "griffin", "harding", "hilary", "hussein", "ida", "hiram", "obama"
+  "berger", "caton", "chadburn", "charlotte", "clanin", "corry", "cushing", "deane", "hoopes", "isaac",
+  "jahnkow", "jaffe", "jenn", "jacqueline", "maestri", "mcallister", "morley", "navarro", "petajan", "ridge",
+  "rory", "shylow", "sean", "sneath", "stallman", "trease", "vlaanderen", "wahlquist", "walcott", "wheelwright", 
 };
 
 
