@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---            Copyright (C) 2006, 2007, 2008, 2009, 2010  QRW Software
+--         Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-02-21 09:55:12 -0700 (Sun, 21 Feb 2010) $
---   $Revision: 4589 $
+--   $Date: 2011-11-05 11:04:14 -0600 (Sat, 05 Nov 2011) $
+--   $Revision: 4923 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -361,10 +361,9 @@ int main(int argc, char* argv[])
 	    break;
 	}
 
-
-	if (!verbose && chunk_num % 64 == 0)
+	if (!verbose && (chunk_num + 1) % 64 == 0)
 	{
-	    printf("%u - %u  used: %lld\n", chunk_num / 64, chunk_num * BLOCKS_IN_CHUNK, private_blocks_used - last_total);
+	    printf("%u - %u  used: %u + %lld  subtotal: %u + %lld\n", chunk_num / 64, (chunk_num + 1) * BLOCKS_IN_CHUNK, BIT_MAP_BLOCKS * 64, private_blocks_used - last_total, (chunk_num + 1) * BIT_MAP_BLOCKS, private_blocks_used);
 	    fflush(stdout);
 	    last_total = private_blocks_used;
 	}
@@ -391,9 +390,9 @@ int main(int argc, char* argv[])
 	}
     }
 
-    if (!verbose)
+    if (!verbose && chunk_num % 64 != 0)
     {
-	printf("%u - %u  used: %lld\n", chunk_num / 64, chunk_num * BLOCKS_IN_CHUNK, private_blocks_used - last_total);
+	printf("%u - %u  used: %u + %lld  subtotal: %u + %lld\n", chunk_num / 64, chunk_num * BLOCKS_IN_CHUNK, BIT_MAP_BLOCKS * 64, private_blocks_used - last_total, chunk_num * BIT_MAP_BLOCKS, private_blocks_used);
 	fflush(stdout);
     }
 
