@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---            Copyright (C) 2006, 2007, 2008, 2009, 2010  QRW Software
+--         Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-06-24 07:35:28 -0600 (Thu, 24 Jun 2010) $
---   $Revision: 4657 $
+--   $Date: 2011-11-05 11:04:14 -0600 (Sat, 05 Nov 2011) $
+--   $Revision: 4923 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -98,6 +98,16 @@ static void control_c_handler(int signal_num)
 }
 
 
+static void md5_digest_to_string(uint8* digest, char* string, size_t size)
+{
+    int i;
+
+    assert(size <= MD5_DIGEST_SIZE * 2 + 1);
+
+    for (i = 0; i < MD5_DIGEST_SIZE; i++) snprintf(string + 2 * i, 3, "%02x", digest[i]);
+}
+
+
 int main(int argc, char* argv[])
 {
     int obj_file_desc;
@@ -108,7 +118,7 @@ int main(int argc, char* argv[])
     int i;
     int j;
     size_t bytes_read;
-    int num_blocks;
+    uint64 num_blocks;
     uint64 used_private_blocks;
     uint32 chunk_block_offset;
     uint32 blocks_on_disk;
@@ -118,6 +128,7 @@ int main(int argc, char* argv[])
     uint32 ref;
     uint32 hash;
     int chunk_num;
+    uint32 new_chunks;
     uint32 used_chunks;
     uint32 total_chunks;
     uint32 empty_chunks;
@@ -129,6 +140,8 @@ int main(int argc, char* argv[])
     bool full_copy = false;
     uint32 num_chunks_block_size_mismatch;
     uint32 num_chunks_md5_mismatch;
+    char source_md5_string[MD5_DIGEST_SIZE * 2 + 1];
+    char destination_md5_string[MD5_DIGEST_SIZE * 2 + 1];
 
 
     if (argc != 2 && argc != 3)
@@ -289,9 +302,16 @@ int main(int argc, char* argv[])
     j = 0;
     for (i = 0; i < nwos_used_private_chunks; i++)
     {
-	while (j < used_chunks && chunk_info[j].ref != nwos_chunk_info[i].ref) j++;
-	if (j == used_chunks) break;
-	j++;
+	if ((nwos_chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) == 0)    /* allow the destination to have empty chunks */
+	{
+	    if (chunk_info[j].ref == nwos_chunk_info[i].ref) j++;
+	}
+	else
+	{
+	    while (j < used_chunks && chunk_info[j].ref != nwos_chunk_info[i].ref) j++;
+	    if (j == used_chunks) break;
+	    j++;
+	}
     }
 
     if (i < nwos_used_private_chunks)   /* refs didn't all match */
@@ -307,12 +327,20 @@ int main(int argc, char* argv[])
     num_chunks_md5_mismatch = 0;
 
     j = 0;
+    new_chunks = 0;
     empty_chunks = 0;
     for (i = 0; i < nwos_used_private_chunks; i++)
     {
 	while (j < used_chunks && chunk_info[j].ref != nwos_chunk_info[i].ref)
 	{
-	    if ((chunk_info[j].flags_used & CHUNK_INFO_USED_MASK) == 0) empty_chunks++;
+	    if ((chunk_info[j].flags_used & CHUNK_INFO_USED_MASK) == 0)
+	    {
+		empty_chunks++;
+	    }
+	    else
+	    {
+		new_chunks++;
+	    }
 	    j++;
 	}
 
@@ -324,15 +352,27 @@ int main(int argc, char* argv[])
 	j++;
     }
 
-    if (j < used_chunks && (chunk_info[j].flags_used & CHUNK_INFO_USED_MASK) == 0) empty_chunks++;
+    while (j < used_chunks)
+    {
+	if ((chunk_info[j].flags_used & CHUNK_INFO_USED_MASK) == 0)
+	{
+	    empty_chunks++;
+	}
+	else
+	{
+	    new_chunks++;
+	}
 
-    printf("Number of new chunks: %u\n", used_chunks - nwos_used_private_chunks);
+	j++;
+    }
+
+    printf("Number of new chunks: %u\n", new_chunks);
     printf("Number of empty chunks: %u\n", empty_chunks);
     printf("Number of chunks that changed: %u\n", num_chunks_md5_mismatch);
 
     assert(num_chunks_md5_mismatch >= num_chunks_block_size_mismatch);
 
-    if (nwos_used_private_chunks == used_chunks - empty_chunks && num_chunks_md5_mismatch == 0)
+    if (new_chunks == 0 && num_chunks_md5_mismatch == 0)
     {
 	printf("\nArchives are the same, sync not needed!\n\n");
 	nwos_terminate_storage();
@@ -540,7 +580,11 @@ int main(int argc, char* argv[])
 
 			if (full_copy)
 			{
-			    assert(num_blocks == nwos_used_private_blocks);
+			    if (num_blocks != nwos_used_private_blocks)
+			    {
+				fprintf(stderr, "ERROR: number of blocks mismatch - blocks copied: %llu  used blocks: %llu\n", num_blocks, nwos_used_private_blocks);
+				break;
+			    }
 			}
 		    }
 		}
@@ -555,7 +599,7 @@ int main(int argc, char* argv[])
 
     nwos_finish_progress_bar();
 
-    printf("Number of blocks: %d\n", num_blocks);
+    printf("Number of blocks: %llu\n", num_blocks);
 
     if (blocks_with_bad_ids > 0)
     {
@@ -566,8 +610,7 @@ int main(int argc, char* argv[])
 
     nwos_terminate_storage();
 
-    snprintf(msg, sizeof(msg), "Number of blocks written: %d  chunks_used: %u",
-	     num_blocks, nwos_used_private_chunks);
+    snprintf(msg, sizeof(msg), "Number of blocks written: %llu  chunks_used: %u", num_blocks, nwos_used_private_chunks);
     nwos_log(msg);
     printf("%s\n", msg);
 
@@ -579,10 +622,6 @@ int main(int argc, char* argv[])
 	fprintf(stderr, "%s\n", msg);
     }
 
-    if (source_len > 0)
-    {
-	nwos_free(source);
-    }
 
     /* check to see if the chunk_info tables matched */
 
@@ -597,39 +636,84 @@ int main(int argc, char* argv[])
 
 	/* first make sure the references all match */
 
-	for (i = 0, j = 0; i < used_chunks && j < nwos_used_private_chunks; i++, j++)
+	i = 0;
+	j = 0;
+
+	while (i < used_chunks || j < nwos_used_private_chunks)
 	{
-	    if (chunk_info[i].ref != nwos_chunk_info[j].ref)
+	    assert(i <= used_chunks);
+	    assert(j <= nwos_used_private_chunks);
+
+	    if (i == used_chunks)     /* just check destination for empty */
 	    {
-		if ((chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) == 0)   /* skip over empty */
+		if ((nwos_chunk_info[j].flags_used & CHUNK_INFO_USED_MASK) != 0)
 		{
-		    j--;
+		    fprintf(stderr, "Error: destination archive (%s) has non-empty chunk not in source archive (%s): %llx\n", source, destination, nwos_chunk_info[j].ref);
+		}
+
+		j++;
+	    }
+	    else if (j == nwos_used_private_chunks)     /* just check source for empty */
+	    {
+		if ((chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) != 0)
+		{
+		    fprintf(stderr, "Error: source archive (%s) has non-empty chunk not in destination archive (%s): %llx\n", destination, source, chunk_info[i].ref);
+		}
+
+		i++;
+	    }
+	    else
+	    {
+		if (chunk_info[i].ref == nwos_chunk_info[j].ref)
+		{
+		    if ((chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) != (nwos_chunk_info[j].flags_used & CHUNK_INFO_USED_MASK))
+		    {
+			fprintf(stderr, "Error: number of blocks used in chunk %llx mismatch - source (%s): %u  destination (%s): %u\n", chunk_info[i].ref,
+				source, (chunk_info[i].flags_used & CHUNK_INFO_USED_MASK),
+				destination, (nwos_chunk_info[j].flags_used & CHUNK_INFO_USED_MASK));
+		    }
+
+		    if (memcmp(chunk_info[i].md5_digest, nwos_chunk_info[j].md5_digest, MD5_DIGEST_SIZE) != 0)
+		    {
+			md5_digest_to_string(chunk_info[i].md5_digest, source_md5_string, sizeof(source_md5_string));
+			md5_digest_to_string(nwos_chunk_info[j].md5_digest, destination_md5_string, sizeof(destination_md5_string));
+			fprintf(stderr, "Error: MD5 checksums don't match in %llx chunks - source (%s): %s  destination (%s): %s\n", chunk_info[i].ref,
+				source, source_md5_string,
+				destination, destination_md5_string);
+		    }
+
+		    i++;
+		    j++;
 		}
 		else
 		{
-		    break;
+		    if ((chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) == 0)   /* skip over empty */
+		    {
+			i++;
+		    }
+		    else if ((nwos_chunk_info[j].flags_used & CHUNK_INFO_USED_MASK) == 0)   /* skip over empty */
+		    {
+			j++;
+		    }
+		    else
+		    {
+			printf("Reference mismatch - %s [%d]: %llx    %s [%d]: %llx\n",
+			       source,      i, i < used_chunks ? chunk_info[i].ref : 0,
+			       destination, j, j < nwos_used_private_chunks ? nwos_chunk_info[j].ref : 0);
+			break;
+		    }
 		}
 	    }
-	    else   /* references match */
-	    {
-		if ((chunk_info[i].flags_used & CHUNK_INFO_USED_MASK) != (nwos_chunk_info[j].flags_used & CHUNK_INFO_USED_MASK)) num_chunks_block_size_mismatch++;
-		if (memcmp(chunk_info[i].md5_digest, nwos_chunk_info[j].md5_digest, MD5_DIGEST_SIZE) != 0) num_chunks_md5_mismatch++;
-	    }
-	}
-
-	if (i < used_chunks || j < nwos_used_private_chunks)   /* refs didn't all match */
-	{
-	    printf("Reference mismatch - %s [%d]: %llx    %s [%d]: %llx\n",
-		   source,      i, i < used_chunks ? chunk_info[i].ref : 0,
-		   destination, j, j < nwos_used_private_chunks ? nwos_chunk_info[j].ref : 0);
-	}
-	else
-	{
-	    printf("Number of chunks with block counts that mismatch:  %u\n", num_chunks_block_size_mismatch);
-	    printf("Number of chunks with MD5 checksums that mismatch: %u\n", num_chunks_md5_mismatch);
 	}
    }
 
+
+    if (source_len > 0)
+    {
+	nwos_free(source);
+	source = NULL;
+    }
+
     nwos_terminate_storage();
 
     return control_c_received;    /* exit with 0 if normal completion, exit with 1 if control-C was hit */
