@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-09-12 12:52:54 -0600 (Sun, 12 Sep 2010) $
---   $Revision: 4727 $
+--   $Date: 2010-11-12 11:36:30 -0700 (Fri, 12 Nov 2010) $
+--   $Revision: 4838 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -50,6 +50,7 @@
 --
 */
 
+#include <ctype.h>
 #include <fnmatch.h>
 #include <limits.h>
 #include <stdio.h>
@@ -57,29 +58,35 @@
 #include <string.h>
 
 #include "objectify.h"
+#include "strlcxx.h"        /* in case strlcpy and strlcat are not provided by the system */
 #include "time_stamp.h"
 
 static struct section {
   char* anchor;
   char* section;
   char* prefix;
+  char* homepage;
 } sections[] = 
   {
-    { "blag",         "Blag",              "BLAG" },
-    { "centos",       "CentOS",            "CentOS" },
-    { "dragora",      "Dragora",           "dragora" },
-    { "edubuntu",     "Edubuntu",          "edubuntu" },
-    { "gnewsense",    "gNewSense",         "gnewsense" },
-    { "gobuntu",      "Gobuntu",           "gobuntu" },
-    { "jeos",         "Jeos (Ubuntu)",     "jeos" },
-    { "kubuntu",      "Kubuntu",           "kubuntu" },
-    { "mythbuntu",    "Mythbuntu",         "mythbuntu" },
-    { "trisquel",     "Trisquel",          "trisquel" },
-    { "ubuntu",       "Ubuntu",            "ubuntu" },
-    { "ubuntustudio", "UbuntuStudio",      "ubuntustudio" },
-    { "venenux",      "Venenux",           "venenux" },
-    { "warty",        "Ubuntu Warty 4.10", "warty" },
-    { "xubuntu",      "Xubuntu",           "xubuntu" },
+    { "blag",         "Blag",              "BLAG",         "http://www.blagblagblag.org/" },
+    { "centos",       "CentOS",            "CentOS",       "http://www.centos.org/" },
+    { "dragora",      "Dragora",           "dragora",      "http://dragora.usla.org.ar/wiki/:en:wiki" },
+    { "dynebolic",    "Dyne:bolic",        "dynebolic",    "http://dynebolic.org/" },
+    { "edubuntu",     "Edubuntu",          "edubuntu",     "http://edubuntu.org/" },
+    { "fedora",       "Fedora",            "yarrow",       "http://fedoraproject.org/" },
+    { "gnewsense",    "gNewSense",         "gnewsense",    "http://www.gnewsense.org/Main/HomePage" },
+    { "gobuntu",      "Gobuntu",           "gobuntu",      "https://wiki.ubuntu.com/Gobuntu" },
+    { "jeos",         "Jeos (Ubuntu)",     "jeos",         "https://help.ubuntu.com/community/JeOS" },
+    { "knoppix",      "Knoppix",           "KNOPPIX",      "http://www.knoppix.net/" },
+    { "kubuntu",      "Kubuntu",           "kubuntu",      "http://www.kubuntu.org/" },
+    { "mythbuntu",    "Mythbuntu",         "mythbuntu",    "http://www.mythbuntu.org/" },
+    { "objectify",    "Objectify",         "objectify",    "https://savannah.nongnu.org/projects/objectify" },
+    { "trisquel",     "Trisquel",          "trisquel",     "http://trisquel.info/en" },
+    { "ubuntu",       "Ubuntu",            "warty",        "http://www.ubuntu.com/" },
+    { "ubuntustudio", "UbuntuStudio",      "ubuntustudio", "http://ubuntustudio.org/" },
+    { "venenux",      "Venenux",           "venenux",      "http://venenux.org/" },
+    { "xubuntu",      "Xubuntu",           "xubuntu",      "http://xubuntu.org/" },
+    { "yellowdog",    "YellowDog",         "yellowdog",    "http://www.yellowdoglinux.com/" },
   };
 
 static const int num_sections = sizeof(sections) / sizeof(struct section);
@@ -91,6 +98,20 @@ static size_t get_path_object_size(void* file_path_obj)
     return sizeof(C_struct_File_Path) + ((C_struct_File_Path*)file_path_obj)->count;
 }
 
+
+static bool has_prefix(char* string, char* prefix)
+{
+    while (*prefix != '\0')
+    {
+	if (*string == '\0' || *string != *prefix) return false;
+	string++;
+	prefix++;
+    }
+
+    return true;
+}
+
+
 void print_unknown(int field_width)
 {
     int i;
@@ -238,16 +259,215 @@ void get_assoc_path(ObjRef* assoc_ref, char* name, size_t name_size)
 }
 
 
-bool has_prefix(char* string, char* prefix)
+void insert_character(char* s, char c, int index, size_t size)
 {
-    while (*prefix != '\0')
+    int length;
+    int i;
+
+    length = strlen(s);
+
+    assert(length + 2 <= size);
+    assert(index < length);
+
+    for (i = length; i >= index; i--) s[i+1] = s[i];
+
+    s[index] = c;
+}
+
+
+void reverse_characters(char* string, int first, int pivot, int last)
+{
+    char save[64];
+    int i;
+    int j;
+
+    assert(pivot - first + 1 < sizeof(save));
+
+    for (i = first; i < pivot; i++)
     {
-	if (*string == '\0' || *string != *prefix) return false;
-	string++;
-	prefix++;
+	save[i-first] = string[i];
     }
 
-    return true;
+    j = first;
+
+    while (i <= last)
+    {
+	string[j] = string[i];
+	i++;
+	j++;
+    }
+
+    i = 0;
+    while (j <= last)
+    {
+	string[j] = save[i];
+	i++;
+	j++;
+    }
+}
+
+
+/* This function gets the file name, but morphs a bit so the sort order is better */
+/* For example fixes it so that ubuntu-10.04 follows ubuntu-9.10                  */
+
+void get_assoc_sort_path(ObjRef* assoc_ref, char* name, size_t name_size)
+{
+    int i;
+
+    get_assoc_path(assoc_ref, name, name_size);
+
+    /* take care of some special cases */
+
+    if (strcmp(name, "kubuntu-kde4.0-i386.iso") == 0)
+    {
+	strlcpy(name, "kubuntu-kde4-7.10-i386.iso", name_size);
+    }
+
+    if (strcmp(name, "ubuntu-moblin-remix-9.10-moblin-remix-i386.iso") == 0)
+    {
+	strlcpy(name, "ubuntu-9.10-moblin-remix-i386.iso", name_size);
+    }
+
+    if (strcmp(name, "liveBLAG-70000.iso") == 0)
+    {
+	strlcpy(name, "BLAG-70000-live.iso", name_size);
+    }
+
+    if (has_prefix(name, "warty-release"))
+    {
+	name[0] = 'u';
+	name[1] = 'b';
+	name[2] = 'u';
+	name[3] = 'n';
+	name[4] = 't';
+	name[5] = 'u';
+	name[6] = '-';
+	name[7] = '4';
+	name[8] = '.';
+	name[9] = '1';
+	name[10] = '0';
+	name[11] = '-';
+	name[12] = 'w';
+    }
+
+    if (has_prefix(name, "ubuntu-server-5.10"))
+    {
+	reverse_characters(name, 7, 14, 18);
+    }
+
+    /* fix to ignore the case of CentOS */
+
+    if (has_prefix(name, "CentOS"))
+    {
+	name[0] = 'c';
+	name[4] = 'o';
+	name[5] = 's';
+    }
+
+    /* Fix up Dyne:bolic releases */
+
+    if (has_prefix(name, "dyne-"))
+    {
+	insert_character(name, 'b', 4, name_size);
+	insert_character(name, 'o', 5, name_size);
+	insert_character(name, 'l', 6, name_size);
+	insert_character(name, 'i', 7, name_size);
+	insert_character(name, 'c', 8, name_size);
+    }
+
+    if (has_prefix(name, "dynebolic") && name[14] == 'i')
+    {
+	insert_character(name, '0', 14, name_size);
+	insert_character(name, '.', 15, name_size);
+    }
+
+
+    /* Fix up early Fedora releases */
+
+    if (has_prefix(name, "yarrow"))
+    {
+	name[0] = 'f';
+	name[1] = 'e';
+	name[2] = 'd';
+	name[3] = 'o';
+	name[4] = 'r';
+	name[5] = 'a';
+
+	insert_character(name, '-', 6, name_size);
+	insert_character(name, '0', 7, name_size);
+	insert_character(name, '1', 8, name_size);
+    }
+
+    if (has_prefix(name, "FC"))
+    {
+	name[0] = 'f';
+	name[1] = 'e';
+
+	insert_character(name, 'd', 2, name_size);
+	insert_character(name, 'o', 3, name_size);
+	insert_character(name, 'r', 4, name_size);
+	insert_character(name, 'a', 5, name_size);
+	insert_character(name, '-', 6, name_size);
+	insert_character(name, '0', 7, name_size);
+    }
+
+    /* Change KNOPPIX to knoppix */
+
+    if (has_prefix(name, "KNOPPIX"))
+    {
+	name[0] = 'k';
+	name[1] = 'n';
+	name[2] = 'o';
+	name[3] = 'p';
+	name[4] = 'p';
+	name[5] = 'i';
+	name[6] = 'x';
+    }
+
+    /* fix to sort special trisquel versions with the regular versions */
+
+    if (has_prefix(name, "trisquel-edu_2.2.2_") || has_prefix(name, "trisquel-pro_2.2.2_"))
+    {
+	reverse_characters(name, 8, 12, 17);
+    }
+
+    if (has_prefix(name, "trisquel-mini_4.0_"))
+    {
+	reverse_characters(name, 8, 13, 16);
+    }
+
+    if (has_prefix(name, "trisquel-netinst_4.0_"))
+    {
+	reverse_characters(name, 8, 16, 19);
+    }
+
+    if (has_prefix(name, "trisquel"))
+    {
+	if (strstr(name, "2.2.2") != NULL || strstr(name, "3.0.1") != NULL)
+	{
+	    name[14] ^= ('_' ^ '-');     /* flip the separator so the sort is nicer */
+	}
+	else if (strstr(name, "3.5") != NULL || strstr(name, "4.0") != NULL)
+	{
+	    name[12] ^= ('_' ^ '-');     /* flip the separator so the sort is nicer */
+	}
+    }
+
+
+    /* insert a zero in front of all single digit numbers */
+
+    if (strlen(name) > 2)       /* the code below assumes the string is at least 3 characters long */
+    {
+	for (i = 1; i < name_size; i++)      /* start at one because there aren't any distros that have a digit in the first character */
+	{
+	    if (name[i+1] == '\0') break;
+
+	    if (ispunct(name[i-1]) && isdigit(name[i]) && ispunct(name[i+1]))
+	    {
+		insert_character(name, '0', i, name_size);
+	    }
+	}
+    }
 }
 
 
@@ -300,13 +520,13 @@ void list_files(Option option)
 
 	if (is_same_object(&object_class, &assoc_class_ref))
 	{
-	    get_assoc_path(&ref_list->references[i], left_name, sizeof(left_name));
+	    get_assoc_sort_path(&ref_list->references[i], left_name, sizeof(left_name));
 
 	    j = i + 1;
 
 	    while (j / 2 > 0)
 	    {
-		get_assoc_path(&sorted_assoc_refs[(j / 2) - 1], right_name, sizeof(right_name));
+		get_assoc_sort_path(&sorted_assoc_refs[(j / 2) - 1], right_name, sizeof(right_name));
 
 		if (strcmp(left_name, right_name) < 0) break;
 
@@ -337,8 +557,8 @@ void list_files(Option option)
 	    /* if there is a right child */
 	    if (k < i - 1)
 	    {
-		get_assoc_path(&sorted_assoc_refs[k - 1], left_name, sizeof(left_name));
-		get_assoc_path(&sorted_assoc_refs[k + 1 - 1], right_name, sizeof(right_name));
+		get_assoc_sort_path(&sorted_assoc_refs[k - 1], left_name, sizeof(left_name));
+		get_assoc_sort_path(&sorted_assoc_refs[k + 1 - 1], right_name, sizeof(right_name));
 
 		if (strcmp(left_name, right_name) < 0)
 		{
@@ -346,8 +566,8 @@ void list_files(Option option)
 		}
 	    }
 
-	    get_assoc_path(&save, left_name, sizeof(left_name));
-	    get_assoc_path(&sorted_assoc_refs[k-1], right_name, sizeof(right_name));
+	    get_assoc_sort_path(&save, left_name, sizeof(left_name));
+	    get_assoc_sort_path(&sorted_assoc_refs[k-1], right_name, sizeof(right_name));
 
 	    if (strcmp(left_name, right_name) >= 0) break;
 
@@ -359,40 +579,6 @@ void list_files(Option option)
 	copy_reference(&sorted_assoc_refs[j - 1], &save);
     }
 
-    /* move the liveBlag back so it is with it's brethern */
-
-    for (i = 0; i < num_files; i++)
-    {
-	get_assoc_path(&sorted_assoc_refs[i], left_name, sizeof(left_name));
-
-	if (has_prefix(left_name, "liveBLAG"))
-	{
-	    copy_reference(&save, &sorted_assoc_refs[i]);
-	    break;
-	}
-    }
-
-    if (i < num_files)
-    {
-	while (i > 1)
-	{
-	    get_assoc_path(&sorted_assoc_refs[i-1], left_name, sizeof(left_name));
-
-	    if (has_prefix(left_name, "BLAG"))
-	    {
-		copy_reference(&sorted_assoc_refs[i], &save);
-		break;
-	    }
-	    else
-	    {
-		copy_reference(&sorted_assoc_refs[i], &sorted_assoc_refs[i-1]);
-	    }
-
-	    i--;
-	}
-
-	copy_reference(&sorted_assoc_refs[i], &save);
-    }
 
     //    printf("Number of files: %d\n", num_files);
 
@@ -408,6 +594,9 @@ void list_files(Option option)
 	if (section < num_sections && has_prefix(left_name, sections[section].prefix))
 	{
 	    printf("  <H2><A NAME=\"%s\">%s</A></H2>\n", sections[section].anchor, sections[section].section);
+
+	    printf("    Home Page: <A HREF=\"%s\">%s</A></BR></BR>\n", sections[section].homepage, sections[section].homepage);
+
 	    section++;
 	}
 
@@ -517,11 +706,15 @@ int main(int argc, char* argv[])
     }
 
     printf("<HEAD>\n");
-    printf("  <TITLE>www.worldwide-database.org: List of Public Files %s</TITLE>\n", title);
+    printf("  <TITLE>www.worldwide-database.org: List of Files %s</TITLE>\n", title);
     printf("</HEAD>\n");
 
+    /* printf("<!--#include virtual=\"header.html\"-->\n"); */    /* server side include */
+
     printf("<BODY BGCOLOR=\"#ffffff\">\n");
 
+    printf("  <CENTER><H1>List of Files %s</H1></CENTER>\n", title);
+
     printf("<P>\n");
 
     printf("<UL>\n");
