@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-01-23 08:10:59 -0700 (Sat, 23 Jan 2010) $
---   $Revision: 4486 $
+--   $Date: 2010-02-10 06:23:12 -0700 (Wed, 10 Feb 2010) $
+--   $Revision: 4560 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -80,6 +80,7 @@ static int    public_file_desc;
 static int    private_file_desc;
 static bool    read_only;
 static bool    modified;
+static bool    total_chunks_modified = false;
 
 ObjRef* nwos_storage_index;
 int     nwos_storage_count;
@@ -496,7 +497,7 @@ bool nwos_terminate_disk_io()
 	nwos_store_public_data(buffer, sizeof(buffer));
 	snprintf(log_msg, sizeof(log_msg), "  used public blocks: %llu", nwos_used_public_blocks);
 #else
-	nwos_store_private_data(buffer, sizeof(buffer), nwos_archive_is_file());
+	nwos_store_private_data(buffer, sizeof(buffer), nwos_archive_is_file() | total_chunks_modified);
 	snprintf(log_msg, sizeof(log_msg), "  total private chunks: %u  used: %u  blocks: %llu", nwos_total_private_chunks, nwos_used_private_chunks, nwos_used_private_blocks);
 #endif
 	nwos_log(log_msg);
@@ -522,6 +523,7 @@ bool nwos_terminate_disk_io()
 	}
 
 	modified = false;
+	total_chunks_modified = false;
 	disk_was_modified = true;
     }
     else
@@ -806,3 +808,16 @@ bool nwos_write_block_to_offset(Archive_Type archive, int64 offset, uint8 block[
 }
 
 
+/* This function is for the archive-resize program */
+
+void nwos_change_total_chunks(uint32 new_chunks)
+{
+    assert(new_chunks >= nwos_used_private_chunks);
+
+    nwos_total_private_chunks = new_chunks;
+
+    modified = true;
+    total_chunks_modified = true;
+}
+
+
