@@ -22,8 +22,11 @@
 --          This file is part of the New World OS and Objectify projects
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
---   For the latest information, source code (SVN), releases, bug and feature
---   request tracking go to:
+--   For the latest information, source code (SVN), releases, and bug tracking
+--   go to:
+--      http://savannah.nongnu.org/projects/objectify
+--
+--   For releases from Alpha_30 and up, bug and feature request tracking go to:
 --      http://sourceforge.net/projects/objectify
 --
 --   For older bug tracking, releases and source code (CVS) prior to the
@@ -37,8 +40,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
---   $Revision: 4184 $
+--   $Date: 2009-10-06 08:06:23 -0600 (Tue, 06 Oct 2009) $
+--   $Revision: 4384 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
