@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---         Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010  QRW Software
+--      Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-09-05 13:15:19 -0600 (Sun, 05 Sep 2010) $
---   $Revision: 4676 $
+--   $Date: 2011-02-13 10:22:12 -0700 (Sun, 13 Feb 2011) $
+--   $Revision: 4863 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -725,6 +725,15 @@ ObjRef* nwos_get_file_class_reference()
 
     return &file_references[2];
 }
+
+
+bool nwos_is_file_class_reference(ObjRef* ref)
+{
+    return is_same_object(nwos_get_file_class_reference(), ref) ||
+           is_same_object(nwos_get_file_002_reference(), ref) ||
+           is_same_object(nwos_get_file_001_reference(), ref);
+}
+
 #endif
 
 
