@@ -39,8 +39,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2010-01-30 08:57:28 -0700 (Sat, 30 Jan 2010) $
-#   $Revision: 4510 $
+#   $Date: 2010-06-30 08:43:02 -0600 (Wed, 30 Jun 2010) $
+#   $Revision: 4662 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -232,6 +232,7 @@ if ! $EXEC/src/apps/file/file-verify --remove-no-shred *; then
    exit 1
 fi
 
+
 echo "---------------------"
 echo " export files..."
 echo "---------------------"
@@ -242,7 +243,19 @@ if ! $EXEC/src/apps/file/file-export computer.c; then
    exit 1
 fi
 
-rmdup ../computer.c.save computer.c
+echo "---------------------"
+echo " don't overwrite..."
+echo "---------------------"
+if $EXEC/src/apps/file/file-export computer.c; then
+   echo ""
+   echo "file-export overwrote computer.c"
+   echo ""
+   exit 1
+fi
+
+if diff -s ../computer.c.save computer.c; then
+   rm -v computer.c
+fi
 
 
 echo "---------------------"
